Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/displayio_sh1107_simpletest.py
    :caption: examples/displayio_sh1107_simpletest.py
    :linenos:
